@@ -47,7 +47,7 @@ func RunControllerServer(servingInfo configv1.HTTPServingInfo, kubeExternal clie
 		return err
 	}
 	sarClient := kubeExternal.AuthorizationV1().SubjectAccessReviews()
-	remoteAuthz, err := authzwebhook.NewFromInterface(sarClient, 5*time.Minute, 5*time.Minute)
+	remoteAuthz, err := authzwebhook.NewFromInterface(sarClient, 5*time.Minute, 5*time.Minute, *authzwebhook.DefaultRetryBackoff())
 	if err != nil {
 		return err
 	}
@@ -62,7 +62,7 @@ func RunControllerServer(servingInfo configv1.HTTPServingInfo, kubeExternal clie
 
 	//handler = apifilters.WithAuthentication(handler, authn, apifilters.Unauthorized(legacyscheme.Codecs, false), nil)
 	handler = apifilters.WithAuthentication(handler, authn, apifilters.Unauthorized(serializer.WithoutConversionCodecFactory{CodecFactory: legacyscheme.Codecs}), nil)
-	handler = apiserverfilters.WithPanicRecovery(handler)
+	handler = apiserverfilters.WithPanicRecovery(handler, requestInfoResolver)
 	handler = apifilters.WithRequestInfo(handler, requestInfoResolver)
 
 	return serveControllers(servingInfo, handler, clientCAs)
